
interesting.points = function(field,fun,niter,xdim,ydim,lon,lat,x.del,y.del,lplot=FALSE) {
	
### finds a set of points identified by the function 'fun' (e.g., 'min' or 'max')
### blocks out the data within x +/- x.del and y+/- y.del, then repeats
## INPUT:
##   FIELD: [XDIM,YDIM] ARRAY OF POINTS
##   FUN: THE FUNCTION FOR IDENTIFYING POINTS (USUALLY 'MAX' OR 'MIN')
##   NITER: NUMBER OF ITERATIONS (NUMBER OF POINTS THAT SATISFY 'FUN')
##	 XDIM: X-DIMENSION OF FIELD
##   YDIM: Y-DIMENSION OF FIELD
##   X.DEL: X-HALF-WIDTH OF BOX TO BE 'BLOCKED OUT'
##   Y.DEL: Y-HALF-WIDTH OF BOX TO BE 'BLOCKED OUT'
##   LPLOT: LOGICAL: PLOT FIELD WITH BLOCKED OUT BOXES?
## OUTPUT: LIST
##   X.PIC: [NITER] X-VALUE OF THE INTERESTING POINTS
##   Y.PIC: [NITER] Y-VALUE OF THE INTERESTING POINTS
##   F.PIC: [NITER] FIELD-VALUE OF THE INTERESTING POINTS


x.pic    = numeric()
y.pic    = numeric()
f.pic    = numeric()
dum      = field
dim(dum) = c(xdim,ydim)

for ( nt in 1:niter ) {
	npic = which(dum==fun(dum,na.rm=TRUE),arr.ind=TRUE)
	if (length(npic) > 1) {print(paste("more than one found"));npic=npic[1,]}
	x.pic[nt] = npic[1]
	y.pic[nt] = npic[2]
	
	f.pic[nt] = dum[x.pic[nt],y.pic[nt]]
	
	x.box = (x.pic[nt]-x.del):(x.pic[nt]+x.del)
	x.box[x.box < 1]    = x.box[x.box < 1   ] + xdim
	x.box[x.box > xdim] = x.box[x.box > xdim] - xdim
	
	y.box = (y.pic[nt]-y.del):(y.pic[nt]+y.del)
	y.box[y.box < 0]    = 1
	y.box[y.box > ydim] = ydim
	
	dum[x.box,y.box] = NA
	if (lplot) plot_latlon_v4(lon,lat,dum,lmaskzero=FALSE)
	
	}
	
list(x.pic=x.pic,y.pic=y.pic,f.pic=f.pic)

}

	