periodogram = function(x) {
## COMPUTES THE PERIODOGRAM OF A VECTOR X USING THE FFT
## ASSUMES THE LENGTH OF X IS EVEN AND HIGHLY COMPOSITE 
##   (E.G., EXPRESSIBLE AS POWERS OF 2,3,5)
# INPUT:
#    X[NTOT]: DATA VECTOR
# OUTPUT:
#    PGRAM[NTOT/2]: VECTOR OF PERIODOGRAM AMPLITUDES AT HARMONIC FREQUENCIES
#      1/N, 2/N, . . ., 1/2 CYCLES PER TIME STEP (A TOTAL NTOT/2 FREQUENCIES)
# COMMENT:
#    TOTAL (BIASED) VARIANCE = 2 * SUM(PGRAM[1:(NTOT/2-1)]) + PGRAM[NTOT/2]

ntot  = length(x)
if ( ntot %% 2 != 0 ) stop('length of x must be even')
x.fft = fft(x)
pgram = Re(x.fft * Conj(x.fft))[1:(ntot/2)+1] / ntot
pgram
}