plot_eof_latlon <- function(data.eof,npic,nens=1,ne.index=1,nbreaks=10) {
	
#### PLOTS EOF AND PC FOR THE 'NPIC' COMPONENT
# INPUT:
#    DATA.EOF: LIST OUTPUT FROM PLOT_LATLON
#    NPIC: THE INDEX OF THE EOF/PC TO BE PLOTTED
#    NENS: NUMBER OF ENSEMBLE MEMBERS (DEFAULT = 1)
#    NE.INDEX: =1 IF THE TIME IS DIMENSIONED AS (NENS,NCON)
#              =2 IF THE TIME IS DIMENSIONED AS (NCON,NENS)
#    NBREAKS: CONTROLS NUMBER OF COLOR BREAKS IN COLOR PLOT (DEFAULT = 10)
	

fexpvar = signif(100*data.eof$fexpvar[npic],2)

lon   = data.eof$lon
lat   = data.eof$lat
neof  = data.eof$neof

nlon  = length(lon)
nlat  = length(lat)

dim(data.eof$eof) = c(nlon*nlat,neof)

par(mfcol=c(2,1),mar=c(4,3,3,2))
ftitle = paste("EOF-",npic," of ",data.eof$dname," (",fexpvar,"%)",sep="")
plot_latlon_v4(lon,lat,data.eof$eof[,npic],nbreaks=nbreaks)
title(main=ftitle)

if ( lon[1] < 0 ) map('world',interior=FALSE,add=T) else map('world2',interior=FALSE,add=T)

if ( length(data.eof$pc) != 0 ) {
	ntot  = length(data.eof$pc[,1])
	nyrs  = ntot/nens
	
	if (length(data.eof$idate[4]) != 0 ) {
		if ( data.eof$idate[4] == "1mo") incr = 1/12
		if ( data.eof$idate[4] == "1yr") incr = 1
		if ( data.eof$idate[4] == "6mo") incr = 1/2
		if ( data.eof$idate[4] == "5yr") incr = 5
	} else incr = 1
	
	if (length(data.eof$idate[3]) != 0 ) {
		year = seq(from=as.numeric(data.eof$idate[3]),by=incr,length.out=nyrs)
	} else { 
		year = 1:nyrs
	}
	
	if ( nens == 1) {
		plot(year,data.eof$pc[,npic],type="l",xlab="Year",ylab="PC")
	} else {
		yrange= range(data.eof$pc[,npic])
		if ( ne.index == 1) year.rep = rep(year,each=nens) else year.rep = rep(year,nens)
		plot(year.rep,data.eof$pc[,npic],type="p",pch=19,col="blue",xlab="Year",ylab="PC",ylim=yrange)
		pc = data.eof$pc[,npic]
		if ( ne.index == 1) {
			dim(pc) = c(nens,nyrs)
			pcm     = colMeans(pc)
			f       = f.anova.array(pc,1,nens,nyrs)$f
		} else {
			dim(pc) = c(nyrs,nens)
			pcm     = rowMeans(pc)
			f       = f.anova.array(t(pc),1,nens,nyrs)$f
		}
		par(new=TRUE)
		plot(year,pcm,type="b",pch=19,col="red",xlab="",ylab="",axes=FALSE,ylim=yrange)
		if ( nens != 1) title(main=paste("F=",signif(f,2)))
	}
}
	
}


