var.equal.test = function(data1,data2,alpha=0.05) {
### THIS FUNCTION TESTS EQUALITY OF VARIANCE OF TWO 
### IID NORMALLY DISTRIBUTED RANDOM VARIABLES
### 
# INPUT:
#   DATA1: [N1]-DIMENSIONAL VECTOR OF DATA
#   DATA2: [N2]-DIMENSIONAL VECTOR OF DATA
#   ALPHA: SIGNIFICANCE LEVEL OF THE TEST (DEFAULT = 5%)
# OUTPUT LIST:
#   F.MAX: RATIO OF VARIANCE, CONSTRUCTED TO BE GREATER THAN 1
#   F.CRIT: THE UPPER CRITICAL THRESHOLD OF SIGNIFICANCE
#   PVAL: P-VALUE OF THE F.MAX RATIO
#   VAR1: UNBIASED ESTIMATE OF THE VARIANCE OF DATA1
#   VAR2: UNBIASED ESTIMATE OF THE VARIANCE OF DATA2
#   RATIO: VAR1/VAR2
#   RATIO.LOWER: LOWER LIMIT OF ALPHA CONFIDENCE INTERVAL FOR VARIANCE RATIO
#   RATIO.UPPER: UPPER LIMIT OF ALPHA CONFIDENCE INTERVAL FOR VARIANCE RATIO

n1    = length(data1); n2    = length(data2)

mean1 = sum(data1)/n1; mean2 = sum(data2)/n2

var1  = sum((data1-mean1)^2)/(n1-1)
var2  = sum((data2-mean2)^2)/(n2-1)

if ( var1 > var2) {
  f.max  = var1/var2
  f.crit = qf(alpha/2,n1-1,n2-1,lower.tail=FALSE)
  pval   = 2*pf(f.max,n1-1,n2-1,lower.tail=FALSE)
} else {
  f.max  = var2/var1
  f.crit = qf(alpha/2,n2-1,n1-1,lower.tail=FALSE)
  pval   = 2*pf(f.max,n2-1,n1-1,lower.tail=FALSE)
}

f.upper = qf(alpha/2,n1-1,n2-1,lower.tail=FALSE)
f.lower = qf(alpha/2,n1-1,n2-1,lower.tail=TRUE)

ratio       = var1/var2
ratio.lower = ratio/f.upper
ratio.upper = ratio/f.lower

list(f.max=f.max,f.crit=f.crit,pval=pval,var1=var1,var2=var2,
  ratio=ratio,ratio.lower=ratio.lower,ratio.upper=ratio.upper)

}